import "./tasks/varscan.wdl" as varscan
import "./tasks/annovar.wdl" as annovar
import "./tasks/vcf2maf.wdl" as vcf2maf


workflow {{ project_name }} {
    
    String sample_id
    File normal_recaled_bam
    File tumor_recaled_bam
    File normal_recaled_bam_index
    File tumor_recaled_bam_index

    String varscan_docker
    String annovar_docker
    String maftools_docker
    
    File ref_dir
    String fasta
    File dbmills_dir
    String db_mills
    File dbsnp_dir
    String dbsnp
    File regions
    String disk_size
    String cluster_config
    
    File database

    call varscan.varscan as varscan {
        input:
        ref_dir=ref_dir,
        fasta=fasta,
        normal_bam=normal_recaled_bam,
        tumor_bam=tumor_recaled_bam,
        normal_bam_index=normal_recaled_bam_index,
        tumor_bam_index=tumor_recaled_bam_index,
        sample=sample_id,
        varscan_docker=varscan_docker,	
        disk_size=disk_size,
        cluster_config=cluster_config
    }

    call annovar.annovar as annovar {
        input:
        docker=annovar_docker,
        database=database,
        varscan_snp=varscan.varscan_snp,
        varscan_indel=varscan.varscan_indel,
        sample=sample_id,
        cluster_config=cluster_config,
        disk_size=disk_size
    }

    call vcf2maf.vcf2maf as vcf2maf {
        input:
        docker=maftools_docker,
        multianno_varscan_snp_txt=annovar.multianno_varscan_snp_txt,
        multianno_varscan_indel_txt=annovar.multianno_varscan_indel_txt,
        sample=sample_id,
        cluster_config=cluster_config,
        disk_size=disk_size
    }
}